@@ -1,13 +1,15 @@
 import json
-from typing import Dict, List, Optional
+from typing import TYPE_CHECKING, Dict, List, Optional
 
 import networkx as nx
 import numpy as np
-import rdkit.Chem
 from nfp.frameworks import tf
 from nfp.preprocessing import features
 from nfp.preprocessing.mol_preprocessor import MolPreprocessor, SmilesPreprocessor
 
+if TYPE_CHECKING:  # only for type checking
+    import rdkit.Chem
+
 
 class xTBPreprocessor(MolPreprocessor):
     def __init__(
@@ -63,7 +65,7 @@ class xTBPreprocessor(MolPreprocessor):
             self.xtb_mol_features = xtb_mol_features
 
     def create_nx_graph(
-        self, mol: rdkit.Chem.Mol, jsonfile: str, **kwargs
+        self, mol: "rdkit.Chem.Mol", jsonfile: str, **kwargs
     ) -> nx.DiGraph:
 
         with open(jsonfile, "r") as f:
